/*  Copyright (c) 2005 Romain BONDUE
    This file is part of RutilT.

    RutilT is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    RutilT is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with RutilT; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
/** \file IfaceProtocolCodes.h
    \author Romain BONDUE
    \date 09/06/2006 */
#ifndef __IFACEPROTOCOLCODES_H__
#define __IFACEPROTOCOLCODES_H__



namespace nsNet
{
    enum IfaceProtocolCodes_e {DeviceNameC, DhcpC, StaticIpC, UpC, DownC};
 
    const char* const IfaceHandler ("IfaceHandler");

} // namespace nsNet

#endif // __IFACEPROTOCOLCODES_H__
